#
# spec file for package ipsec-tools
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ipsec-tools
Summary:        IPsec Utilities
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
Version:        0.8.0
Release:        12.8
Url:            http://ipsec-tools.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/ipsec-tools/ipsec-tools-%{version}.tar.bz2
Source2:        sysconfig.racoon
Source3:        setkey.conf.sample
Source4:        racoon.pam
Source5:        racoon.service
Source6:        racoon-setkey.service

Patch0:         racoon.conf_macros.patch
Patch1:         racoon.psk.patch
Patch2:         ipsec-tools-0.7.3-linkerflag.patch
Patch3:         ipsec-tools-0.8.0-nodevel.patch
Patch4:         ipsec-tools-0.8.0-certasn1txtbroken.patch
Patch5:         racoon-no-md5.patch
Patch6:         racoon-fips-rsa.patch
Patch7:         fix-gssapi-null-dereference.patch
Patch8:         fix_plog_initialization.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %insserv_prereq %fillup_prereq
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  krb5-devel
BuildRequires:  libtool
BuildRequires:  linux-glibc-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam
BuildRequires:  pam-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(systemd)

%if 0%{?suse_version} >= 1100
BuildRequires:  fdupes
BuildRequires:  libselinux-devel
%endif
Provides:       racoon
%{?systemd_requires}
%description
This is the IPsec-Tools package.  This package is needed to really make
use of the IPsec functionality in the version 2.5 and 2.6 Linux
kernels.  This package builds:

- libipsec, a PFKeyV2 library

- setkey, a program to directly manipulate policies and SAs

- racoon, an IKEv1 keying daemon

These sources can be found at the IPsec-Tools home page at:
http://ipsec-tools.sourceforge.net/

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
./bootstrap
sed -i 's|-Werror||g' configure

%build
export PATH=$PATH:/usr/lib/mit/bin
%configure \
	--disable-shared \
	--libexecdir=%{_libdir} \
	--sysconfdir=/etc/racoon \
	--sharedstatedir=/run \
	--localstatedir=/run \
        --with-kernel-headers="/usr/include" \
	--enable-dpd \
	--enable-hybrid \
	--enable-frag \
	--enable-natt=yes \
	--enable-gssapi=yes \
	--enable-stats=yes \
	--enable-adminport \
	--with-libpam \
%if 0%{?suse_version} >= 1100
	--enable-security-context=yes \
%else
	--enable-security-context=no \
%endif
	--with-libldap
make 

%check
make check

%install
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/pam.d
install -m 0644 %{S:4} $RPM_BUILD_ROOT/etc/pam.d/racoon
%{__install} -d $RPM_BUILD_ROOT/etc/racoon/cert
# unify the permissions of psk.txt - fdupes is sensitive on permissions now (bnc#784670)
chmod 0600 src/racoon/samples/psk.txt
install -m 0600 src/racoon/samples/psk.txt $RPM_BUILD_ROOT/etc/racoon/
install -m 0644 src/racoon/samples/racoon.conf $RPM_BUILD_ROOT/etc/racoon/
cp -v $RPM_SOURCE_DIR/setkey.conf.sample $RPM_BUILD_ROOT/etc/racoon/setkey.conf
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 $RPM_SOURCE_DIR/sysconfig.racoon $RPM_BUILD_ROOT/var/adm/fillup-templates/
# manage doc
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/packages/%{name}/examples/{setkey,racoon}
cp -rv src/racoon/samples $RPM_BUILD_ROOT/usr/share/doc/packages/%{name}/examples/racoon
cp -v src/setkey/sample* $RPM_BUILD_ROOT/usr/share/doc/packages/%{name}/examples/setkey
for i in ChangeLog NEWS README; do
	install -D -m 0644 $i $RPM_BUILD_ROOT/usr/share/doc/packages/%{name}/
done
#some rpmlint stuff
%if 0%{?suse_version} >= 1100
%fdupes -s $RPM_BUILD_ROOT/
%endif

install -d %{buildroot}%{_tmpfilesdir}
echo 'd /run/racoon 0700 root root -' > %{buildroot}%{_tmpfilesdir}/racoon.conf
install -D -m 0644 %{S:5} %{buildroot}%{_unitdir}/racoon.service
install -D -m 0644 %{S:6} %{buildroot}%{_unitdir}/racoon-setkey.service

%pre
%service_add_pre racoon.service racoon-setkey.service

%post
%{fillup_only -n racoon}

# _tmpfilesdir is not defined in systemd macros up to openSUSE 13.2
%{!?_tmpfilesdir: %global _tmpfilesdir %{_libexecdir}/tmpfiles.d }

# Use %%tmpfiles_create when 13.2 is oldest in support scope
/usr/bin/systemd-tmpfiles --create %{_tmpfilesdir}/racoon.conf || :

%service_add_post racoon.service racoon-setkey.service

%preun
%service_del_preun racoon.service racoon-setkey.service

%postun
%service_del_postun racoon.service racoon-setkey.service 

%files
%defattr(-,root,root)
%{_unitdir}/*.service
%{_tmpfilesdir}/racoon.conf
%doc /usr/share/doc/packages/%{name}/
%config(noreplace) /etc/racoon/psk.txt
%config(noreplace) /etc/racoon/racoon.conf
%config(noreplace) /etc/racoon/setkey.conf
%config /etc/pam.d/racoon
%dir /etc/racoon
%dir /etc/racoon/cert
/usr/sbin/racoon
/usr/sbin/racoonctl
/usr/sbin/setkey
/usr/sbin/plainrsa-gen
/var/adm/fillup-templates/sysconfig.racoon
%{_mandir}/man*/*

%changelog
* Wed Oct  5 2016 jbohac@suse.cz
- fix_plog_initialization.patch (bsc#1002216)
  Move logging initialization up to prevent crash with -l.
* Fri Mar  4 2016 dbond@suse.de
- (bsc#968926) add
  /usr/bin/systemd-tmpfiles --create %%{_tmpfilesdir}/racoon.conf || :
  to %%post section of .spec file to cause the creation of the
  /run/racoon directory upon rpm installation.
* Tue Jun  9 2015 meissner@suse.com
- racoon.psk.patch: disabled one IP entry from the examples.
* Fri May 22 2015 jbohac@suse.com
- fix-gssapi-null-dereference.patch: Fix a GSSAPI NULL pointer
  dereference in racoon (bsc#931989, CVE-2015-4047)
* Thu Apr 23 2015 meissner@suse.com
- racoon-fips-rsa.patch: Increase minimum RSA exponent to RSA_F4
  aka 65537 (mandated by FIPS 140-2). bsc#928313
* Mon Jan 19 2015 meissner@suse.com
- racoon-no-md5.patch: Use sha1 instead of md5 during hashing received
  packets to allow FIPS usage. allow md5 during vendor id hashing,
  as this seems to be come from over the wire. bsc#905780
* Tue Jul  8 2014 meissner@suse.com
- ipsec-tools-0.8.0-certasn1txtbroken.patch:
  disable the certificate test in src/racoon/eaytest.c as the
  internal X.509 ASN.1 string presentation was changed in openssl
  and the test currently does not work.
* Thu Mar 13 2014 jbohac@suse.cz
- add RemainAfterExit=yes to the .service file (bnc#856625)
* Fri Jan 10 2014 jbohac@suse.cz
- upgrade to version 0.8.0:
  o Fix authentication method ambiguity with kerberos and xauth
  o RFC2253 compliant escaping of asn1dn identifiers (Cyrus Rahman)
  o Local address code rewrite to speed things up
  o Improved MIPv6 support (Arnaud Ebalard)
  o ISAKMP SA (phase1) rekeying
  o Improved scheduler (faster algorithm, support monotonic clock)
  o Handle RESPONDER-LIFETIME in quick mode
  o Handle INITIAL-CONTACT in from main mode too
  o Rewritten event handling framework for admin port
  o Ability to initiate IPsec SA through admin port
  o NAT-T Original Address handling (transport mode NAT-T support)
  o clean NAT-T - PFkey support
  o support for multiple anonymous remoteconfs
  o Remove various obsolete configuration options
  o A lot of other bug fixes, performance improvements and clean ups
- Remove ipsec-tools-linux-3.7-compat.diff which caused bnc#867055
  by including wrong headers; fix by installing
  linux-glibc-devel and including /usr/include for kernel headers
* Thu Sep 19 2013 crrodriguez@opensuse.org
- remove unused racoon.init from the package, it was
  already removed from the spec file in the previous change.
* Thu Sep 19 2013 crrodriguez@opensuse.org
- Add systemd support, systemctl enable racoon.service
  also enables helper optional service racoon-setkey
- /etc/sysconfig/racoon was never created, fix that.
* Thu Jan 31 2013 mlin@suse.com
- Add ipsec-tools-linux-3.7-compat.diff(partly from openwrt)
  * since pfkeyv2.h moved to include/uapi/linux as
    http://lwn.net/Articles/507794/ explained, make the compiler found
    header in valid path. there is a discussion about this issue at
    https://dev.openwrt.org/ticket/12813
* Wed Oct 31 2012 mvyskocil@suse.com
- unify the permissions of psk.txt to avoid false duplicate warnings
  from fdupes (bnc#784670)
* Tue Jan 31 2012 meissner@suse.de
- remove suse_update_config macro usage
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep  4 2011 mkubecek@suse.cz
- create /var/run/racoon in the init script rather than including
  it in the package as it doesn't work if /var/run is on tmpfs
  (bnc#710277)
* Sun May 15 2011 chris@computersalat.de
- remove Author from description
- add racoon.psk patch
* Wed May  4 2011 idoenmez@novell.com
- Add ipsec-tools-0.7.3-linkerflag.patch: remove wrong linker flag
- Add ipsec-tools-0.7.2-nodevel.patch: don't install development
  files, instead of manually removing them in the spec file.
- Drop no_werror.patch: Remove Werror flag by sed, its all over the
  configure file, old patch was incomplete anyway.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Oct  6 2009 chris@computersalat.de
- cleanup spec
  o sorted sections
  o simplify clean
  o sort install section
  o sort files section
- added missing /etc/racoon/cert DIR
* Fri Sep 18 2009 chris@computersalat.de
- cleanup spec
  o sorted TAGS
  o added configure macro
- rpmlint
  o added fdupes
- fix selinux build
  o if suse_version >= 1100
* Thu Jun 11 2009 jbohac@suse.cz
- upgrade to 0.7.3
- integrated security patch
- enabled selinux support (--enable-security-context=yes)
* Thu Jun 11 2009 jbohac@suse.cz
- fix_sockaddr_overflow_in_ipsec_doi.c.diff (bnc#506710)
* Wed May  6 2009 jbohac@suse.cz
- Upgrade to 0.7.2
- fixed some rpmlint warnings/errors
- racoon.conf_macros.patch updates the .in file, not the result
- added /etc/pam.d/racoon
- added --with-libldap
* Tue Sep 23 2008 jbohac@suse.cz
- fixed a memory leak in PH1 (bnc#416906, CVE-2008-3652)
* Thu Aug 14 2008 jbohac@suse.cz
- Upgrade to 0.7.1
  o Fixes a memory leak when invalid proposal received
  o Some fixes in DPD
  o do not set default gss id if xauth is used
  o fixed hybrid enabled builds
  o fixed compilation on FreeBSD8
  o cleanup in network port value manipulation
  o gets ports from SADB_X_EXT_NAT_T_[SD]PORT if present in purge_ipsec_spi()
  o Generates a log if cert validation has been disabled by configuration
  o better handling for pfkey socket read errors
  o Fixes in yacc / bison stuff
  o new plog() macro (reduced CPU usage when logging is disabled)
  o Try to works better with huge SPD/SAD
  o Corrected modecfg option syntax
  o Many other various fixes...
* Wed Nov  7 2007 jbohac@suse.cz
- Upgrade to 0.7
* Thu Apr 12 2007 jbohac@jikos.cz
- Fix a DoS in isakmp_info_recv (CVE-2007-1841, 260791)
* Thu Mar 29 2007 aj@suse.de
- Add flex and bison to BuildRequires.
* Thu May  4 2006 jbohac@suse.cz
- fixed a segfault in GSSAPI initialization (#172196)
* Thu May  4 2006 jbohac@suse.cz
- the /var/run/racoon directory was missing from the package
  which prevented racoon from starting (#170552) - fixed
- fixed unexpanded macros in racoon.conf (#170552)
* Tue Mar 21 2006 jbohac@suse.cz
- upgrade to 0.6.5 (bugfix release)
  - Fixed zombie PH1 handler when isakmp_send() fails in
    isakmp_ph1resend()
  - Temporary fix for /32 subnets parsing.
  - make software behave as the documentation advertise for
    INTERNAL_NETMASK4. Keep the old INTERNAL_MASK4 to
    avoid breaking backward compatibility.
  - Fixed / cleaned up signal handling.
- added --with-libpam and --enable-adminport (#159647)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 jbohac@suse.cz
- fixed build
* Tue Dec 13 2005 jbohac@suse.cz
- upgrade to 0.6.4
- added krb5 support ( --enable-gssapi)
- added statistics logging support ( --enable-stats)
* Wed Nov 23 2005 jbohac@suse.cz
- upgrade to 0.6.3 - fixes #134834 and an openssl incompatibility
  issue
* Tue Nov  8 2005 jbohac@suse.cz
- fixed build for s390
* Thu Oct 20 2005 jbohac@suse.cz
- upgraded to version 0.6.2
- enabled NAT-T
- fixed build with current openssl
* Wed Aug 31 2005 jbohac@suse.cz
- fixed permissions for /etc/racoon/psk.txt (bug #114383)
* Tue Aug 23 2005 jbohac@suse.cz
- upgrade to version 0.6.1
* Wed Aug  3 2005 jbohac@suse.cz
- fixed build on beta (disabled -Werror again)
* Tue Aug  2 2005 cthiel@suse.de
- fixed build
* Tue Aug  2 2005 jbohac@suse.cz
- upgrade to version 0.6
* Thu May  5 2005 jbohac@suse.cz
- upgrade to version 0.5.2
- disabled -Werror, because bison-generated code would not compile
* Wed Apr 13 2005 jbohac@suse.cz
- upgrade to version 0.5.1
- fixed compilation warning/errors regarding char/int signedness
* Wed Apr 13 2005 jbohac@suse.cz
- upgrade to version 0.5.1
- fixed compilation warning/errors regarding char/int signedness
* Wed Mar 16 2005 jbohac@suse.cz
  The patch in the previous release was not applied correctly; fixed.
* Tue Mar 15 2005 jbohac@suse.cz
- security fix - insecure header parsing (Bug ID: 64726)
* Sat Feb 19 2005 lmuelle@suse.de
- Update to version 0.5.
* Wed Jan  5 2005 jbohac@suse.cz
- update to ipsec-tools-0.5-rc1
* Thu Nov 18 2004 mludvig@suse.cz
- Update to version 0.4
* Mon Sep 13 2004 ro@suse.de
- undef __P first to make it build
* Tue Aug 10 2004 mludvig@suse.cz
- Update to 0.4rc1
* Tue Jun 15 2004 mludvig@suse.cz
- Update to 0.3.3 to fix a X.509 cert verification security bug.
  (http://marc.theaimsgroup.com/?l=bugtraq&m=108726102304507&w=2)
* Mon May 17 2004 mludvig@suse.cz
- Fixed comment in racoon.conf (#40576)
* Wed Apr 21 2004 mludvig@suse.cz
- Update to 0.3.1 to fix CAN-2004-0403
* Thu Apr 15 2004 mludvig@suse.cz
- Update to final 0.3. We had all patches in the
  package anyway...
* Thu Apr  8 2004 mludvig@suse.cz
- Fixed setkey to support multiline commands in interactive mode.
- Added 'exit' command to setkey.
  The two changes fix TAHI/ipsec tests.
- Emit messages about Keep-Alive packets with DEBUG severity
  instead of INFO. With INFO it only polutes syslog every 20s.
* Mon Apr  5 2004 mludvig@suse.cz
- Fixed X.509 security bug (#38373)
* Thu Apr  1 2004 mludvig@suse.cz
- Report received SADB_X_NAT_T_NEW_MAPPING message.
- Avoid segfault with unknown PF_KEY messages.
- Move encmode update out of the loop. NAT-T now works
  even with more than one proposal.
* Tue Mar 30 2004 mludvig@suse.cz
- Rewritten the testsuite to avoid
  failures on 32b platforms.
* Fri Mar 26 2004 mludvig@suse.cz
- Handle input lines one by one in interactive mode
  (preventing premature exit on syntax error).
* Thu Mar 25 2004 mludvig@suse.cz
- Update to 0.3rc4:
  - Fixed adding "null" encryption via 'setkey'.
  - Fixed segfault when using AES in Phase1 with OpenSSL>=0.9.7
  - Fixed NAT-T in aggresive mode.
  - Fixed testsuite and added testsuite run into make check.
* Tue Mar 23 2004 mludvig@suse.cz
- Fix segfault with AES.
- Enable testsuite.
* Mon Mar 22 2004 mludvig@suse.cz
- Fix "null" encryption setup in setkey.
* Fri Mar 19 2004 mludvig@suse.cz
- Fix duplicate ipsec service (#36575)
- Update to 0.3rc3
* Thu Mar 11 2004 mludvig@suse.cz
- Update to 0.3rc2
* Mon Mar  8 2004 mludvig@suse.cz
- Add sysconfig and init.d files.
* Fri Mar  5 2004 mludvig@suse.cz
- Include samples config files in the RPM.
* Thu Mar  4 2004 mludvig@suse.cz
- update to 0.3rc1
* Tue Feb  3 2004 mludvig@suse.cz
- Update to 0.2.4
* Mon Jan 26 2004 ro@suse.de
- updated neededforbuild "kernel-source-26" -> "kernel-source"
* Thu Jan 15 2004 mludvig@suse.cz
- update to ipsec-tools-0.2.3
* Sat Jan 10 2004 adrian@suse.de
- remove obsolete %%run_ldconfig
* Tue Dec 23 2003 mludvig@suse.cz
- Recognize IPSEC_DIR_FWD when dumping SPD.
* Fri Dec 19 2003 mludvig@suse.cz
- Added many fixes gathered from the mailing list.
- Added support for specifying SA lifebytes.
* Wed Dec 17 2003 garloff@suse.de
- Package ipsec-tools 0.2.2.
